Package: CSwR
Title: Companion to the Book "Computational Statistics with R"
Version: 0.1.3
Authors@R: 
    c(
      person(
        "Niels Richard",
        "Hansen",
        email = "Niels.R.Hansen@math.ku.dk",
        role = "aut",
        comment = c(ORCID = "0000-0003-3883-365X")
      ),
      person(
        "Johan",
        "Larsson",
        role = c("aut", "cre"),
        email = "johan@jolars.co",
        comment = c(ORCID = "0000-0002-4029-5945")
      )
    )
Description: Provides data sets and functions used in the book
    "Computational Statistics with R" (<https://cswr.nrhstat.org>).
Depends: R (>= 3.5.0)
Imports: bench, ggplot2, rlang
Suggests: covr, spelling, testthat (>= 2.1.0)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Language: en-US
URL: https://jolars.github.io/CSwR-Package/, https://cswr.nrhstat.org/
BugReports: https://github.com/jolars/CSwR-Package/issues
License: MIT + file LICENSE
NeedsCompilation: no
Packaged: 2026-05-28 07:19:54 UTC; jola
Author: Niels Richard Hansen [aut] (ORCID:
    <https://orcid.org/0000-0003-3883-365X>),
  Johan Larsson [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4029-5945>)
Maintainer: Johan Larsson <johan@jolars.co>
Repository: CRAN
Date/Publication: 2026-06-01 08:40:20 UTC
Built: R 4.5.2; ; 2026-06-01 09:28:20 UTC; unix
