% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tracer.R
\name{plotter}
\alias{plotter}
\title{Constructor of plotter expression}
\usage{
plotter(y, col = "black", lty = "solid", pch = 1)
}
\arguments{
\item{y}{a name of a symbol to plot}

\item{col}{point and line color}

\item{lty}{line type}

\item{pch}{plot symbol}
}
\value{
a quoted expression
}
\description{
The plotter function returns a quoted expression that adds points
to a current plot. For use with tracer and terminator objects to
iteratively update plots during long running function evaluations.
}
\examples{
plotter("i")
}
