% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terminator.R
\name{print.terminator}
\alias{print.terminator}
\title{Print terminator information}
\usage{
\method{print}{terminator}(x, ...)
}
\arguments{
\item{x}{a terminator object}

\item{...}{other arguments (currently ignored)}
}
\value{
The list of objects from the terminator's evaluation environment,
returned invisibly.
}
\description{
Print terminator information
}
\examples{
term <- terminator(quote(i >= 3), print = FALSE)

for (i in 1:5) {
  if (term$terminator()) {
    break
  }
}

print(term, all.names = TRUE)
}
