% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tracer.R
\name{summary.tracer}
\alias{summary.tracer}
\alias{print.tracer}
\title{Summarize and print trace information}
\usage{
\method{summary}{tracer}(object, ...)

\method{print}{tracer}(x, ...)
}
\arguments{
\item{object}{a tracer object}

\item{...}{other arguments (currently ignored)}

\item{x}{a tracer object}
}
\value{
\code{summary} returns a data frame (of class trace) with columns
containing the values
of the traced objects, and if time is traced an additional column, \code{.time},
containing the cumulative runtime in seconds.
}
\description{
Summarize and print trace information
}
\examples{
tr <- tracer("i", Delta = 0)

for (i in 1:3) {
  tr$tracer()
}

summary(tr)
print(tr)
}
