% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{vegetables}
\alias{vegetables}
\title{Vegetable sale}
\format{
A data frame with 1066 rows and 3 columns:
\describe{
\item{\code{sale}}{a numeric vector. Number of items sold in a week}
\item{\code{normalSale}}{a numeric vector. Estimated normal sale that week}
\item{\code{store}}{a character vector. Id of the different stores}
}
}
\source{
Obtained by package author.
}
\usage{
vegetables
}
\description{
Weekly sale of frozen vegetables in different stores.
}
\keyword{datasets}
