% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tracer.R
\name{autoplot.tracer}
\alias{autoplot.tracer}
\alias{autoplot.trace}
\title{Plot results from a trace}
\usage{
\method{autoplot}{tracer}(object, y, ...)

\method{autoplot}{trace}(object, y, log = TRUE, ...)
}
\arguments{
\item{object}{a trace or tracer object}

\item{y}{the name of the traced object to plot}

\item{...}{additional arguments passed to}

\item{log}{logical. Should the y-axis be on a log-scale. Default is TRUE.}
}
\value{
a ggplot object
}
\description{
Plots the value of a traced object on a log-scale against runtime.
}
\examples{
tr <- tracer("i", Delta = 0)

for (i in 1:3) {
  tr$tracer()
}

ggplot2::autoplot(tr, i)
}
