% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CSwR-package.R
\docType{package}
\name{CSwR-package}
\alias{CSwR}
\alias{CSwR-package}
\title{CSwR: Companion to the Book "Computational Statistics with R"}
\description{
Provides data sets and functions used in the book "Computational Statistics with R" (\url{https://cswr.nrhstat.org}).
}
\seealso{
Useful links:
\itemize{
  \item \url{https://jolars.github.io/CSwR-Package/}
  \item \url{https://cswr.nrhstat.org/}
  \item Report bugs at \url{https://github.com/jolars/CSwR-Package/issues}
}

}
\author{
\strong{Maintainer}: Johan Larsson \email{johan@jolars.co} (\href{https://orcid.org/0000-0002-4029-5945}{ORCID})

Authors:
\itemize{
  \item Niels Richard Hansen \email{Niels.R.Hansen@math.ku.dk} (\href{https://orcid.org/0000-0003-3883-365X}{ORCID})
}

}
\keyword{internal}
